==> dlna-mnt-gui-2017.07-11-any.pkg.tar.xz: usr/local/bin/dlna-mnt.sh <==
#!/bin/bash
v=170130 #sfs
#http://sergeytroshin.ru/articles/dlna/
#server
#https://geektimes.ru/post/256946/
#client android
#https://www.maketecheasier.com/dlna-streaming-apps-android/
m="`mount |awk '/^djmount / {print $3}'`"
T(){
[ "`pgrep -f "yad --text=<b>Клиент DLNA"`" ] && return
yad --text="<b>Клиент DLNA монтировал</b>
в $d
<i>Левый клик - открыть
Правый клик - меню</i>" --notification --image=dlna  \
    --command='defaultfilemanager "'$d'"' \
    --menu='gtk-disconnect!bash -c "sudo umount "'$d'" & kill $YAD_PID"' \
    &
}
TST(){ 
if [ "$1" ] ;then
    T ; ntf -i "Клиент DNLA запущен" "Остановить - в трее" &
    exit
fi
}
TST "$m"

S(){
[ "$1" ] && o="-o $1"
#wt -o "sudo mkdir -p "$2"" && 
sudo mkdir -p "$2"
#er="`exec sudo djmount -derror $o "$2" 2>&1`"
er="`sudo djmount  $o "$2" 2>&1 &`"
if [ "`pidof djmount`" ];then
    T 
    ntf -q "DLNA ресурсы" "монтированы в '$d'

Открыть файл-менеджером?" && 
    defaultfilemanager "$d" &
else
    ntf -a "Не удалось монтировать DLNA ресурсы" "$er " &
fi
exit
}

TST "$d"
[ "$1" ] &&  S "$1" "$2" 

s="/home/`sfsusr`/.config/autostart/dlna-mnt.desktop"
e=djmount
t="<b><big>DLNA клиент</big></b>: монтирует
все dlna-сервера домашней сети"


if [ "`pidof $e`" ];then
    [ "`pgrep -f "yad --text=DLNA"`" ] || T
    ntf -e "Клиент DLNA запущен" "Остановить - нажатием иконки в трее" && exit 1
else sudo pkill -f "yad --text=Клиент DLNA"
fi

#ED(){ leafpad "$cfg" ; exit ; } #; export -f ED

Y(){
k="iocharset=UTF-8,ro,allow_other"
export d="/mnt/dlna" ; sudo mkdir -p "$d"
yad --title="Клиент DLNA v.$v" \
    --text="$t" \
    --image="dlna" \
    --window-icon="dlna" \
    --fixed --image-on-top --center \
    --field=gtk-help:BTN 'defaultbrowser "https://github.com/mbarbon/djmount"' \
    --form \
    --field="Параметры монтирования" "$k" \
    --field="Точка монтирования":DIR "$d" \
    --field="запускать при старте системы:CHK" "$1" \
    --button=gtk-connect:0 \
    --button=gtk-cancel:2  

#    --field="Доп. параметры" "${6} $7 $8 $9 $10"\
#    --XXfield="часов:NUM" "0!1..60!2!2" \
#    --XXfield="запрос пароля для возобновления работы!lock:BTN" 'bash -c "pass.sh &"'\
#    --separator='\n' 
#    | sudo passwd "$U" #>/dev/null
}

[ -f "$s" ] && s1=TRUE
y="`Y $s1`"
[ "$?" = "0" ] || exit
echo $y
export d="`echo "$y" |awk -F"|" '{print $3}'`"
o="`echo "$y" |awk -F"|" '{print $2}'`" 
a="`echo $y| awk -F"|" '{print $4'}'`"
#exit

AS(){
mkdir -p "`dirname "$s"`"
echo "\
[Desktop Entry]
Type=Application
Icon=dlna
Name=DLNA клиент
Name[ru]=DLNA клиент
Comment[ru]=подключение медиа-контентом сети
Exec=dlna-mnt.sh $o "$d"
" > "$s"
}
echo "astart=$a"
TST
if [ "$a" = "TRUE" ];then
    ntf -q "Добавить в автозагрузку системы запуск Клиента DLNA ?"  && AS 
else  
    [ -f "$s" ] && wt "rm $s" 
fi

S "$o" "$d"

==> dlna-mnt-gui-2018.04-10-any.pkg.tar.xz: usr/local/bin/dlna-mnt.sh <==
#!/bin/bash
v=170130 #sfs
#http://sergeytroshin.ru/articles/dlna/
#server
#https://geektimes.ru/post/256946/
#client android
#https://www.maketecheasier.com/dlna-streaming-apps-android/
m="`mount |awk '/^djmount / {print $3}'`"
T(){
[ "`pgrep -f "yad --text=<b>Клиент DLNA"`" ] && return
yad --text="<b>Клиент DLNA монтировал</b>
в $d
<i>Левый клик - открыть
Правый клик - меню</i>" --notification --image=dlna  \
    --command='defaultfilemanager "'$d'"' \
    --menu='gtk-disconnect!bash -c "sudo umount "'$d'" & kill $YAD_PID"' \
    &
}
TST(){ 
if [ "$1" ] ;then
    T ; ntf -i "Клиент DNLA запущен" "Остановить - в трее" &
    exit
fi
}
TST "$m"

S(){
[ "$1" ] && o="-o $1"
#wt -o "sudo mkdir -p "$2"" && 
sudo mkdir -p "$2"
#er="`exec sudo djmount -derror $o "$2" 2>&1`"
er="`sudo djmount  $o "$2" 2>&1 &`"
if [ "`pidof djmount`" ];then
    T 
    ntf -q "DLNA ресурсы" "монтированы в '$d'

Открыть файл-менеджером?" && 
    defaultfilemanager "$d" &
else
    ntf -a "Не удалось монтировать DLNA ресурсы" "$er " &
fi
exit
}

TST "$d"
[ "$1" ] &&  S "$1" "$2" 

s="/home/`sfsusr`/.config/autostart/dlna-mnt.desktop"
e=djmount
t="<b><big>DLNA клиент</big></b>: монтирует
все dlna-сервера домашней сети"


if [ "`pidof $e`" ];then
    [ "`pgrep -f "yad --text=DLNA"`" ] || T
    ntf -e "Клиент DLNA запущен" "Остановить - нажатием иконки в трее" && exit 1
else sudo pkill -f "yad --text=Клиент DLNA"
fi

#ED(){ leafpad "$cfg" ; exit ; } #; export -f ED

Y(){
k="iocharset=UTF-8,ro,allow_other"
export d="/mnt/dlna" ; sudo mkdir -p "$d"
yad --title="Клиент DLNA v.$v" \
    --text="$t" \
    --image="dlna" \
    --window-icon="dlna" \
    --fixed --image-on-top --center \
    --field=gtk-help:FBTN 'defaultbrowser "https://github.com/mbarbon/djmount"' \
    --form \
    --field="Параметры монтирования" "$k" \
    --field="Точка монтирования":DIR "$d" \
    --field="запускать при старте системы:CHK" "$1" \
    --button=gtk-connect:0 \
    --button=gtk-cancel:2  

#    --field="Доп. параметры" "${6} $7 $8 $9 $10"\
#    --XXfield="часов:NUM" "0!1..60!2!2" \
#    --XXfield="запрос пароля для возобновления работы!lock:BTN" 'bash -c "pass.sh &"'\
#    --separator='\n' 
#    | sudo passwd "$U" #>/dev/null
}

[ -f "$s" ] && s1=TRUE
y="`Y $s1`"
[ "$?" = "0" ] || exit
echo $y
export d="`echo "$y" |awk -F"|" '{print $3}'`"
o="`echo "$y" |awk -F"|" '{print $2}'`" 
a="`echo $y| awk -F"|" '{print $4'}'`"
#exit

AS(){
mkdir -p "`dirname "$s"`"
echo "\
[Desktop Entry]
Type=Application
Icon=dlna
Name=DLNA клиент
Name[ru]=DLNA клиент
Comment[ru]=подключение медиа-контентом сети
Exec=dlna-mnt.sh $o "$d"
" > "$s"
}
echo "astart=$a"
TST
if [ "$a" = "TRUE" ];then
    ntf -q "Добавить в автозагрузку системы запуск Клиента DLNA ?"  && AS 
else  
    [ -f "$s" ] && wt "rm $s" 
fi

S "$o" "$d"
